@@ -160,7 +160,7 @@ def SimpleConsoleMenuBlock(menuName,menuItems,inputQuestion,autoAddQuit = False,
         else:
             return choose
 
-print(SimpleConsoleMenuBlock('menu','item1;item2;item3;item4;item5','Number:',True,True))
+# print(SimpleConsoleMenuBlock('menu','item1;item2;item3;item4;item5','Number:',True,True))
 
 # ╭─────────────╮
 # │    lorem    │
